#!/usr/bin/env python
import json
import os

import sys
import tornado.web
import tornado.ioloop
from tornado.log import enable_pretty_logging
from git_analyzer import GitAnalyzer
import Settings

enable_pretty_logging()


EX_OK = getattr(os, "EX_OK", 0)
EX_USAGE = getattr(os, "EX_USAGE", 64)


class UsageError(Exception):
    def __init__(self, msg):
        self.msg = msg


class Application(tornado.web.Application):
    def __init__(self):
        handlers = [
            (r"/update", MainHandler),
            (r"/js/(.*)", tornado.web.StaticFileHandler, {"path": Settings.JAVASCRIPT_PATH}),
            (r"/css/(.*)", tornado.web.StaticFileHandler, {"path": Settings.CSS_PATH}),
            (r"/(.*)", tornado.web.StaticFileHandler, {"path": Settings.STATIC_PATH, "default_filename": "index.html"}),
        ]

        tornado.web.Application.__init__(self, handlers)


class MainHandler(tornado.web.RequestHandler):
    def post(self):
        if self.request.body:
            try:
                json_data = json.loads(self.request.body)
                repo_url = json_data['repo_url']
            except ValueError:
                message = 'Unable to parse JSON.'
                self.send_error(400, message=message)  # Bad Request
                return

            git_parser = GitAnalyzer()
            git_parser.init_from_url(repo_url)
            git_parser.write_data_to_file('static/data.json')


def main(argv=None):
    if argv is None:
        argv = sys.argv

    try:
        if len(argv) != 1:
            raise UsageError("Usage:  %s" % sys.argv[0])

        app = Application()
        app.listen(3880)
        tornado.ioloop.IOLoop.current().start()

        return EX_OK

    except UsageError, err:
        print >>sys.stderr, err.msg
        return EX_USAGE


if __name__ == "__main__":
    sys.exit(main())
